@@ -153,12 +153,12 @@ class ListEndpoint(object):
             disallowed = ', '.join(list(data_keys - all_fields))
             raise ValueError('Data dictionary contains fieldnames unknown to the Sharepoint list model (Disallowed field names: %s)' % disallowed)
 
-    def getItems(self, rowLimit=999999999):
+    def getItems(self, rowLimit=999999999, viewName=None):
         """ Return all list items without further filtering """
-        items = self.service.GetListItems(self.list_id, rowLimit=rowLimit)
+        items = self.service.GetListItems(self.list_id, viewName=viewName, rowLimit=rowLimit)
         return [self._serializeListItem(item) for item in items.listitems.data.row]
 
-    def getItem(self, item_id):
+    def getItem(self, item_id, viewName=None):
         """ Return all list items without further filtering """
         query0= Element('ns1:query')
         query = Element('Query')
@@ -173,7 +173,6 @@ class ListEndpoint(object):
         eq.append(value)
         viewfields = Element('ViewFields')
         viewfields.append(Element('FieldRef').append(Attribute('Name', self.primary_key)))
-        viewName = Element('viewName')
         queryOptions = Element('queryOptions')
         result = self.service.GetListItems(self.list_id, 
                                           viewName=viewName, 
@@ -185,14 +184,23 @@ class ListEndpoint(object):
             return self._serializeListItem(result.listitems.data.row)
         return []
 
-    def query(self, **kw):
-        """ A generic query API. All list field names can be passed
-            to query() together with the query values. All subqueries
-            are combined using AND. All search criteria must perform
-            an exact match. A better implementation of query() may
-            support the 'Contains' or 'BeginsWith' query options
-            (as given through CAML).
+    def query(self, mode='exact', viewName=None, **kw):
+        """ A generic query API. All list field names can be passed to query()
+            together with the query values. All subqueries are combined using AND.
+            All search criteria must perform an exact match. A better
+            implementation of query() may support the 'Contains' or 'BeginsWith'
+            query options (as given through CAML). The mode=exact ensures an exact
+            match of all query parameter. mode=contains performs a substring search
+            across *all* query parameters. mode=beginswith performs a prefix search
+            across *all* query parameters.
         """
+
+        if not mode in ('exact', 'contains', 'beginswith'):
+            raise ValueError('"mode" must be either "exact", "beginswith" or "contains"')
+
+        # map mode parameters to CAML query options
+        query_modes = {'exact' : 'Eq', 'beginswith' : 'BeginsWith', 'contains' : 'Contains'}
+
         query0= Element('ns1:query')
         query = Element('Query')
         query0.append(query)
@@ -203,21 +211,21 @@ class ListEndpoint(object):
             and_= Element('And')
             where.append(and_)
             where = and_
+
         # build query 
         for k, v in kw.items():
             if not k in self.all_fields:
                 raise ValueError('List definition does not contain a field "%s"' % k)
                 
-            eq = Element('Eq')
-            where.append(eq)
+            mode = Element(query_modes[mode])
+            where.append(mode)
             fieldref = Element('FieldRef').append(Attribute('Name', k))
             value = Element('Value').append(Attribute('Type', self.model[k]['Type'])).setText(v)
-            eq.append(fieldref)
-            eq.append(value)
+            mode.append(fieldref)
+            mode.append(value)
 
         viewfields = Element('ViewFields')
         viewfields.append(Element('FieldRef').append(Attribute('Name', self.primary_key)))
-        viewName = Element('viewName')
         queryOptions = Element('queryOptions')
         result = self.service.GetListItems(self.list_id, 
                                           viewName=viewName, 
